---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: bug
assignees: ''

---

## Describe the bug

A clear and concise description of what the bug is, including error messages.

## To Reproduce

Steps to reproduce the behavior. Attach any input file that might be required.

## Expected behavior

A clear and concise description of what you expected to happen.

## Screenshots

If applicable, add screenshots to help explain your problem.

## Context

Please, complete the following to better understand the system you are using to run MUSE.

- Operating system (eg. Windows 10):
- MUSE version (eg. 1.0.1):
- Installation method (eg. pipx, pip, development mode):
- Python version (you can get this running `python --version`):
